<?php
/**
 * User Interface shared resources configuration
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2009 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 2.0.0
 */

/**
 * Active links counter
 *
 * @param string $type: type of link
 * @return string: utf8 caption
 */
function pubActiveLinks($type){
	$nb=0;
	foreach ($_ENV['uiResourcePublishTokens'] as $k=>$v) if($v['type']==$type) $nb++;
	return '<b style="position:absolute;bottom:2;right:2">'.str_replace('%1',$nb,cfCaption('publishActiveLinks')).'</b>';
}

require(INCLUDE_DIR.'outputFunctions.php');
require(INCLUDE_DIR.'explorerFunctions.php');

// Indicate an in-application display
$_ENV['configurationEnvironment']='application';

// Memorize panel selection
cfGUpdateVar('uiResourcePublishPanel','');

// Store all transfers tokens into ENV var so it's not reloaded by every included script
$_ENV['uiResourcePublishTokens']=efTokensRead();

$shownItems=cfArrayValuesToKeys(array('social','resource','download','video','image','audio'));
foreach ($shownItems as $type) {$itemStyle[$type]='';}

// Drag & droped file(s)
if(isset($_POST['filesDroped'])){
	$files=explode('|',$_POST['filesDroped']);
}

// Context menu file(s) passed to publish tab
if(cfGGetVar('uiResourceShellAction') && cfGGetVar('uiResourceAccordion')=='publish'){
	$files=cfGGetVar('uiResourceShellAction');
}

// Context menu or drag & drop
if(isset($files)){
	// Save for use if user confirmed publish creation
	cfGSetVar('uiResourceShellFiles',$files,true);

	// And destroy uiResourceShellAction so next sync refresh doesn't display form
	cfGSetVar('uiResourceShellAction',false,true);

	$presetFile=$files[0];

	// Set available publications
	$shownItems=array('download');
	if(!is_dir($presetFile)){
		$type=efFileType($presetFile);
		if($type=='audio'||$type=='video'||$type=='image') $shownItems[$type]=1;
	}
	$shownItems=cfArrayValuesToKeys($shownItems);
}

// Fade non-available items
foreach ($itemStyle as $type=>$value) {
	if(!isset($shownItems[$type]))
		$itemStyle[$type]=' style="'.outCssOpacity(20).';cursor:default;text-align:justify"';
	else
		$itemStyle[$type]=' style="text-align:justify" onmouseover="mi(this)" onmouseout="mo(this)" onclick="itemSelect(\''.$type.'\')"';
}



/**
 ***************************************************************************************************************************
 * Insert page HEADER
 ***************************************************************************************************************************
 */
cfInsertHEAD(false);
echo '</head>';
echo '<body>';

// Display a mask over page until it is loaded
echo outLoadMask(false); flush();

$padding=(cfGetBrowser()=='ie')?'2px':'3px 7px 2px 7px';

echo outTableTransparent(false,'height:100%;table-layout:fixed;cursor:pointer');
?>
<script type="text/javascript">
function mi(n){n.className='itemSel'}
function mo(n){n.className='itemUnsel'}
function itemSelect(id){
	try{parent.slideFrame('publish',"<?php echo dirname($_SERVER['PHP_SELF']);?>/publish"+id+".php","down");} catch(e){}
}
function fileDroped(val){wl.postData({'filesDroped':val})}
</script>
<style type="text/css">
.itemUnsel, .itemSel{width:100%;height:100%;padding:4;cursor:pointer;position:relative}
</style>
<tr>
	<td style="height:216px;width:33%;padding:<?php echo $padding;?>">
		<div class="itemUnsel" id="video" <?php echo $itemStyle['video'];?>>
		<div class="frame1Header"><?php echo cfCaption('publishVideoLabel');?></div><br>
<?php
		echo cfCaption('publishVideoDesc','<br><center><img src="/gfx/UI/videoEmbed.gif" style="width:140;height:100;margin:5"></center>');
		echo pubActiveLinks('publishVideo');
?>
		</div>
	</td>
	<td style="height:216px;width:33%;padding:<?php echo $padding;?>">
		<div class="itemUnsel" id="image" <?php echo $itemStyle['image'];?>>
		<div class="frame1Header"><?php echo cfCaption('publishImageLabel');?></div><br>
<?php
		echo cfCaption('publishAudioDesc').'<br><center><img src="/gfx/UI/imageEmbed.gif" style="width:160;height:120;margin:5"></center>';
		echo pubActiveLinks('publishImage');
?>
		</div>
	</td>
	<td style="height:216px;width:33%;padding:<?php echo $padding;?>">
		<div class="itemUnsel" id="audio" <?php echo $itemStyle['audio'];?>>
		<div class="frame1Header"><?php echo cfCaption('publishAudioLabel');?></div><br>
<?php
		echo cfCaption('publishPlaylistDesc','<br><br><center><img src="/gfx/UI/audioEmbed.png" style="width:210;height:19;margin:5"></center><br>');
		echo pubActiveLinks('publishAudio');
?>
		</div>
	</td>
</tr>
<tr>
	<td style="height:216px;width:33%;padding:<?php echo $padding;?>" id="resource">
		<div class="itemUnsel" <?php echo $itemStyle['resource'];?>">
		<div class="frame1Header"><?php echo cfCaption('publishResourceLabel');?></div><br>
<?php
		echo cfCaption('publishResourceDesc','<br><center><img src="/gfx/UI/resourceIntegration.png" style="margin:5px"></center>');
?>
		</div>
	</td>
	<td style="height:216px;width:33%;padding:<?php echo $padding;?>"  id="download">
		<div class="itemUnsel" <?php echo $itemStyle['download'];?>>
		<div class="frame1Header"><?php echo cfCaption('publishDownloadLabel');?></div><br>
<?php
		echo cfCaption('publishDownloadDesc','<br><br><br><center><span style="border:1px solid #CCF;font-weight:bold;margin:5px;padding:4;background:white"><img src="/gfx/fi/med/dl.png" style="vertical-align:middle">'.cfCaption('genDownload').'</span></center><br><br>');
 		echo pubActiveLinks('publishDownload');
?>
		</div>
	</td>
	<td style="height:216px;width:33%;padding:<?php echo $padding;?>" id="social">
		<div class="itemUnsel"<?php echo $itemStyle['social'];?>>
		<div class="frame1Header"><?php echo cfCaption('publishSocialLabel');?></div><br>
		<img src="/gfx/UI/socialMonitor.png"><br><br>
<?php
		echo cfCaption('publishSocialDesc','<br><br><center><img src="/gfx/UI/widgetCompatibility.png"></center><br>');
?>
		<img src="/gfx/UI/twitter.gif" style="margin:4px;vertical-align:middle">
		</div>
	</td>
</tr>
</table>
<input name="dropFileInput" onkeyup="fileDroped(this.value)" style="display:none">
<?php

if(!cfRegistrationData()){
?>
<div id="regsitrationWarning" style="position:absolute;width:80%;left:10%;top:45%;padding-left:10%;padding-right:10%" class="extendedWarning"><br><?php echo outImage(outIcon('alert32'),false,false,'float:left;margin-right:1em;margin-bottom:1em').cfCaption('registrationNeeded');?><br>&nbsp;</div>
<script type="text/javascript">
wl.mask.show(0.8,0,0,0,0,{'background':'#FFF'});
wl.mask.moveAbove(dgi('regsitrationWarning'));
</script>
<?php
}
exit;