<?php
/**
 * Remote resource configuration
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
*
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2005-2008 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 1.1.1
 */

require_once(INCLUDE_DIR.'resourceConfigFunctions.php');
//cfDbg(cfRGetVar('selectedResource'));


/*
 * Verify access rights
*/
if(cfUGetVar('administrator')!=true || !cfGGetVar('remoteAdministrationAuthorized') || !cfRGetVar('advancedAdministration')) outDisplayErrorPage(cfcaption('errorRemoteAdministrationNotAuthorized'),false,true,array('alignBottom'=>true));

// Determine if small-screen tweaks must be applied
$smallScreen=(cfBGetVar('screenSize')=='small' || cfBGetVar('name')=='iPhone');

// Asynchronous header
if(isset($_POST['asyncRequest'])) cfAsyncHeader();

/************************************************************************************************************
 * Process GET/POST commands
 ***********************************************************************************************************/


// Select a resource to configure
if(isset($_POST['config']) && file_exists(cfAppDataDir().'/'.$_POST['config'])) cfRSetVar('selectedResource',$_POST['config']);

// Create a new resource
elseif(isset($_POST['newResType']) && isset($_POST['newResSubType'])){
	$resourceData=array();

	// If passed name
	if(isset($_POST['resourceName'])) $resourceData['name']=cfUTF8Decode($_POST['resourceName'],true,false,false);

	// Create resource (warning: write-close session)
	if($configFilename=rcCreateResource($_POST['newResType'],$_POST['newResSubType'],$resourceData)){
		// Restart session so selectedResource can be saved
		//wSession_start();
		// Select newly created resource
		cfRSetVar('selectedResource',$configFilename);
		// Bind resource to selected users
		if(isset($_POST['users'])) rcResourceAddToUsers($configFilename,explode('/',$_POST['users']));
	}

	// Reload page
	echo cfAsyncXMLJSaction('wl.goURL()');
	die(cfAsyncFooter());
}

// Confirm resource deletion
elseif(isset($_POST['deleteConfirm'])){

	if(file_exists(cfAppDataDir().'/res/'.$_POST['deleteConfirm'])){
		// Count users having this resource
		$nbUsers=0;
		foreach (cfMGetVar('weezoUsers') as $user){
			$nb=0;
			while(isset($user['resource'.$nb])){
				if($user['resource'.$nb]['file']==$_POST['deleteConfirm']){
					$nbUsers++;
					break;
				}
				$nb++;
			}
		}
		// Get resource label
		$res=cfParse_ini_file(cfAppDataDir().'/res/'.$_POST['deleteConfirm']);
		$label=cfUTF8Encode($res['name']);

		// Send confirmation prompt
		if($nbUsers==0) echo(cfAsyncXMLJSaction('deletResConfirm("'.str_replace('"',"''",cfCaption('resConfirmDeleteNo',$label)).'")'));
		else echo cfAsyncXMLJSaction('deletResConfirm("'.str_replace('"',"''",cfCaptionJS('resConfirmDeleteMany',$label,$nbUsers)).'")');
		die(cfAsyncFooter());
	}
}
// Actually delete resource
if(isset($_POST['delete']) && file_exists(cfAppDataDir().'/res/'.$_POST['delete'])){
	$nb=0;

	// Delete resource file and inform application
	rcDeleteResource($_POST['delete']);

	// Reset selected resource
	cfRSetVar('selectedResource',0);

	// Reset active sessions
	require_once(INCLUDE_DIR.'initFunctions.php');
	ifResetResourcesUsers();

	// Sync reload page
	echo cfAsyncXMLJSaction('document.reloadForm.submit()');
	die(cfAsyncFooter());
}
if(!file_exists(cfAppDataDir().'/'.cfRGetVar('selectedResource'))) cfRSetVar('selectedResource',0);

// Disable left-hand side HTML generation for asynchronous resource update
if(!isset($_POST['asyncRequest'])){
?>
<script type="text/javascript">
var initFramesDone=0;
var selectedResource="<?php echo cfRGetVar('selectedResource');?>";
function initFrames(rightOnly){
	<?php if($smallScreen) echo 'dgn("viewport").setAttribute("content", "width=280, user-scalable=yes,initial-scale=1.16"); return;';?>
	if(!dgi('popupNewRes')) return window.setTimeout('initFrames()',50);
	if(!rightOnly) {
		dgi('resDiv').style.height='10px';
		dgi('resTree_outer').style.height='10px';
		dgi('resourceConfigurationPanel').firstChild.style.height='10px';
		initFramesDone=0;
	}
	if(!initFramesDone){
		dgi('mainTable').style.height=(winMe.getInnerHeight()-actualOffsetTop(dgi('mainTable'))-((phpBrowser=="ie")?10:24))+'px';
		dgi('resDiv').style.height=(actualOffsetBottom(dgi('mainTable'))-actualOffsetTop(dgi('resDiv')))+'px';
		var h=(actualOffsetBottom(dgi('resDiv'))-actualOffsetTop(dgi('resTree_outer'))-2*getElementStyle(dgi('resDiv'),'padding-bottom')-((phpBrowser=="ie")?0:2*getElementStyle(dgi('resTree_outer'),'padding-bottom')));
		if(h>0) {
			dgi('resTree_outer').style.height=h+'px';
			initFramesDone=1;
		}
		else setTimeout(initFrames,50);// IE WA
	}
	var node=dgi('resourceConfigurationPanel').firstChild;
	node.style.height=(actualOffsetBottom(dgi('mainTable'))-actualOffsetTop(node)+((phpBrowser=="ie")?0:-getElementStyle(node,'padding-bottom')-getElementStyle(node,'padding-top')-getElementStyle(node,'border-top-width')-getElementStyle(node,'border-bottom-width')))+'px';
}
function winResized(x,y){initFrames()}
function selectRes(node){
	var path=node.getPath().split('/');
	if(path.length==2) return;
	node.setSelected();
	selectedResource=path[2];
	sendData("config="+path[2],"<?php echo $_SERVER['PHP_SELF'];?>");
}
function deleteRes(){
	sendData("deleteConfirm="+selectedResource,"<?php echo $_SERVER['PHP_SELF'];?>");
}
function deletResConfirm(caption){
	if(confirm(caption.replace(/<br>/gi,"\n"))) sendData("delete="+selectedResource,"<?php echo $_SERVER['PHP_SELF'];?>");
}
// Update resource name
function updateResName(args){
	try{treeViews.resTree.getNodeById(args.filename).setLabel(args.name)} catch(e){}
}

D.onload=initFrames();

wl.event.subscribe("resource",updateResName);

</script>
<form name="reloadForm" style="display:none"></form>
<?php

/**
 * Main table
 */
echo outTableTransparent(false,false,'id="mainTable"').'<colgroup><col width="200"><col width="1"><col width="*"></colgroup><tr style="vertical-align:top">';
	echo '<td style="width:200px;vertical-align:top" class="vBanner">';
	echo outDivFrame('frame2 unresizedTV','id="resDiv"');
	echo outFrameHeaderTable('frame2Header',outImage(outIcon('resources'),false,false,'vertical-align:middle;margin-right:0.5em').cfCaption('genResources'),outButton(cfCaption('resNewResource'),'javascript:newResPopupShow()',outIcon('new')));

/************************************************************************************************************
 * Resources list tab
 ***********************************************************************************************************/


// Get all resources
foreach (cfMGetVar('weezoResourcesList') as $id=>$file) $rIni[$file]=cfMGetVar('weezoResData'.$id);
$tree=array('ico'=>outIcon('resources'),'path'=>'top','label'=>'','sub'=>array());

// Regroup resources by type
foreach (array('explorer','webcam','website','blog','bookmarks','tv','misc') as $typeName=>$type){
	// Init type's node
	$tree['sub'][$type]=array(
		'ico'=>'/res/'.$type.'/resourceIconSmall.gif',
		'label'=>cfCaption('res'.ucfirst($type)),
		'unfolded'=>true,
		'sub'=>array());

	// Search type's resources
	foreach ($rIni as $filename=>$ini) if($ini['type']==$type){
		// Do not display administration configuration (phpMyAdmin and weezo administration)
		if($ini['type']=='administration') continue;

		// Initialize selected resource
		if(!cfRGetVar('selectedResource')) cfRSetVar('selectedResource',$filename);

		// Find icon
		if(@$ini['customIcon'] && is_file(cfAppDocRoot().'/gfx/res/'.$ini['customIcon'].'_16.png')) $icoPath='/gfx/res/'.$ini['customIcon'].'_16.png';
		else{
			$icoPath='/res/'.$type.'/'.$ini['subType'].'/resourceIconSmall.gif';
			if(!file_exists(cfAppDocRoot().$icoPath)) {
				$icoPath='/res/'.$type.'/'.$ini['subType'].'/resourceIcon.png';
				if(!file_exists(cfAppDocRoot().$icoPath)) {
					$icoPath='/res/'.$type.'/'.$ini['subType'].'/resourceIcon.gif';
					if(!file_exists(cfAppDocRoot().$icoPath)) $icoPath=outIcon('resources');
				}
			}
		}
		// Set node
		$tree['sub'][$type]['sub'][$filename]=array('ico'=>$icoPath,'label'=>cfUTF8Encode($ini['name']),'sub'=>array());
		if($filename==cfRGetVar('selectedResource')) $tree['sub'][$type]['sub'][$filename]['selected']=true;
	}
}
// Create treeView
$treeView=new treeView('resTree');
$treeView->phpTree=$tree;
$treeView->selectFunction='selectRes';

// Generate HTML
echo $treeView->HTML('frame2',false,false,(($smallScreen)?false:''));
echo "</div></td>\n";

if($smallScreen) echo '</tr><tr>'; else echo "<td>&nbsp;</td>\n";


/************************************************************************************************************
 * Resource configuration tab
 ***********************************************************************************************************/
echo '<td id="resourceConfigurationPanel" style="vertical-align:top">';
}

// Set "configuringResource" used by resourceConfig.php to select resource to be configured
cfRSetVar('configuringResource',cfRGetVar('selectedResource'));

// Asynchronous request: activate outbut buffer in order to send right panel HTML with cfAsyncXMLInnerHTMLbyId()
if(isset($_POST['asyncRequest'])) ob_start();

// Set filename of configured resource
if(isset($_POST['config'])) cfRSetVar('configuringResource',$_POST['config']);

// Include resource configuration script, that will itself include /res/x/y/config.php
$_ENV['rcFalseAsyncResponse']=true; // Indicate resourceConfig.php not to discard synchronous response through ob_start/clean
$_ENV['buttonLessConfig']=cfIsInApp();
require_once(dirname(__FILE__).'/resourceConfig.php');

/**
 * Asynchronous selection of resource or resource configuration save
 */
if(isset($_POST['asyncRequest'])){
	$buffer=ob_get_contents();
	ob_end_clean();

	// Send buffer into resourceConfigurationPanel <td>
	echo cfAsyncXMLInnerHTMLbyId($buffer,'resourceConfigurationPanel');
	echo cfAsyncXMLJSaction('initFrames(1)');
	echo cfAsyncXMLJSaction('W.buttonEnabled=0; if(W.dataInitForm) dataInitForm()');

	die(cfAsyncFooter());
}
echo "</td></tr></table>";



/************************************************************************************************************
 * New Resource popup
 ***********************************************************************************************************/

rcNewResourceForm();
?>