<?php
/**
 * WebTV main file
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
*
 * @category   NA
 * @package    NA
 * @author     Peer 2 World / Nicolas Bruley
 * @copyright  2011 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 3.0
 */



require_once(INCLUDE_DIR.'outputFunctions.php');

/**
 * @desc Return parsed playlist
 *
 * @return array 'url', 'name' [,'audioId'], 'type' (radio or tv)
 */
class WtvPlaylist{
	private $tracks;

	function __construct($playlistName){
		if(cfRGetVar('parsedPlaylist')) return cfRGetVar('parsedPlaylist');

		$playlistName=cfRGetVar('playlistName');

		// Custom specified m3u playlist file
		if($playlistName=='custom'){
			cfRSetVar('playlistCustom',str_replace('*appDir*',cfAppRootDir(),cfRGetVar('playlistCustom')));
			$playlist=file_get_contents(cfRGetVar('playlistCustom'));
			$scheme="/#EXTINF:(0,){0,1}(?P<name>.+)(\r){0,1}\n+(?P<address>.+)(\r){0,1}\n/";
		}
		// m3u file located into playlists directory
		elseif(is_file(dirname(__FILE__).'/playlists/'.$playlistName.'.m3u')){
			$playlist=@file_get_contents(dirname(__FILE__).'/playlists/'.$playlistName.'.m3u');
			$scheme='/#EXTINF:(0,){0,1}(?P<name>.+)(\\r){0,1}\\n+(?P<address>.+)(\\r){0,1}\\n/';
		}
		// Internal playlist descriptor file located into directory: ini formated, with at least url and scheme fields
		elseif(is_file(dirname(__FILE__).'/playlists/'.$playlistName.'.ini')){
			// Parse playlist descriptor file
			$playlistDescriptor=cfParse_ini_file(dirname(__FILE__).'/playlists/'.$playlistName.'.ini');
			if(!isset($playlistDescriptor['url'])||!isset($playlistDescriptor['scheme'])) return false;
			$scheme=$playlistDescriptor['scheme'];

			// Download playlist
			if($scheme) $playlist=cfCURLMultiRequests(array(0=>$playlistDescriptor['url']));

			// If file couldn't be downloaded, use cached version instead
			if(!@$playlist[0]) {
				if(!isset($playlistDescriptor['cache'])) return false;
				$playlist=unserialize(base64_decode($playlistDescriptor['cache']));
				$noCache=true;
			}
			else $playlist=$playlist[0];
		}
		else return false;


		/**
		 * Parse playlist
		 */
		$tracks=array();
		preg_match_all($scheme, $playlist, $matches, PREG_SET_ORDER);

		if (!$matches)	outDisplayErrorPage('Unable to parse playlist file: ' . $playlistName.'<br><div style="text-align:left;width:50%">'.str_replace("\n",'<br>',cfStrTruncate($playlist,0,500)).'</div>');
		$i = 1;

		foreach ($matches as $key => $value){
			$url = NULL;
			$audioid = NULL;

			$name = trim($value["name"]);

			// UTF8 encode channels names (except for "free" playlist)
			if(cfRGetVar('playlistName')!='free') $name=cfUTF8Encode($name); else $name=cfUTF8Decode($name);

			$url = str_replace("\r",'',$value["address"]);

			if (isset($value["audioaddress"])){
				$audioid = $value["audioid"];
				$url = $value["audioaddress"];
			}

			// Local playlists: correct file paths for non-urls
			if($playlistName=='custom' && !strpos($url,'://')){
				$url=str_replace('\\','/',$url);
				if(substr($url,0,1)=='/' || substr($url,1,2)==':/'){
					// Add drive letter if filename starts with "/" under windows
					if(substr($url,0,1)=='/' && substr($url,1,1)!=='/' && WEnv::host()->isWindows()) $completeFilename=substr(cfRGetVar('playlistCustom'),0,1).':'.$url;
				}
				// else prepend playlist file's directory
				else
					$url=cfDirName(cfRGetVar('playlistCustom')).'/'.$url;
			}

			if(substr($name,0,1)=='$' && substr($name,3,1)=='-'){
				$country=substr($name,1,2);
				$name=substr($name,4);
			}
			else $country='';

			$tracks[]=array('name'=>$name, 'country'=>$country, 'url'=>$url, 'audioId'=>$audioid, 'type'=>((@$audioid)?'radio':'tv'));
		}

		$this->tracks=$tracks;
	}

	/**
	 * @desc Return channels
	 *
	 * @param string $channelType ("all", "tv" or "radio")
	 * @return array of tracks
	 */
	function tracks($channelType='all'){
		if($channelType=='all') return $this->tracks;
		$t=array();
		foreach ($this->tracks as $id=>$track) if($track['type']==$channelType) $t[$id]=$track;
		return $t;
	}

	/**
	 * @desc Return number of channels in playlist
	 *
	 * @param string $channelType ("all", "tv" or "radio")
	 */
	function length($channelType='all'){
		if($channelType=='all') return count($this->tracks);
		$nb=0;
		foreach ($this->tracks as $id=>$track) if($track['type']==$channelType) $nb++;
		return $nb;
	}

	/**
	 * @desc return a channel
	 *
	 * @param string $channelId
	 * @return array
	 */
	function track($channelId){
		return @$this->tracks[$channelId];
	}
}


/**
 * @desc Check file access rights
 *
 * @param string $completeFilename: id of channel
 * @return string: stream's url or file name (for custom playlists) on success, false on error
 */
function wtvExtAccessFunction($completeFilename){
	if(!is_numeric($completeFilename)) return false;
	$channelId=$completeFilename;

	if(0) $playlist=new WtvPlaylist('foo');// Zend IDE WA
	$playlist=unserialize(cfRGetVar('playlist'));
	if(!($track=$playlist->track($channelId))) return false;

	// Get stream URL
	$url=$track['url'];

	// Retrieve and parse ASX file
	if(strpos($url,'asx')) $url=wtvGetASXUrl($url);
	// Note: if url couldn't be retrieved from asx url, do nothing and send asx file's URL as is. It might work... or display warning icon

	return $url;
}



/**
 * @desc Initialize resource
 *
 */
function wtvInit(){
	if(cfRGetVar('resourceParametersInitialized')) return;

	cfRInitVar('currentChannel',-1);
	cfRSetVar('allowOriginalVideo',0);	// Disable direct streaming (will do it later...)

	// Enable reencoded video players
	cfRSetVar('reencodedVideo',1);
	cfRSetVar('flvAllowed',1);
	cfRSetVar('ogvAllowed',1);
	cfRSetVar('webmAllowed',1);


	// Set data required by video streamin functions
	cfRInitVar('videoIPhoneBandwidth','high');
	cfRSetVar('flashOutputQuality','high');
	cfRSetVar('flashOutputSizeMax','original');
	cfRSetVar('flashOutputQualityMax','original');
	cfRSetVar('singleVideoWidth','600');
	cfRSetVar('singleVideoHeight','480');
	cfRSetVar('flashOutputSize','original');
	cfRSetVar('flashStream',1);

	// Access rights control function, used for viewVideoFunctions.php: call wtvExtAccessFunction
	cfRSetVar('extAccessFunction','$included=true;require(cfAppDocRoot()."/res/".cfRGetVar("type")."/".cfRGetVar("subType")."/index.php");return wtvExtAccessFunction($completeFilename);');


	// Initialize playlist
	$playlist=new WtvPlaylist(cfRGetVar('playlistName'));
	cfRSetVar('playlist',serialize($playlist));

	if($playlist->length('tv')==0 && $playlist->length('radio')>0) cfRInitVar('displayledChannelsType','radio'); else cfRInitVar('displayledChannelsType','tv');

	// Set user session-persistent vars
	cfSetSavedRVar('currentChannel','displayledChannelsType');


	cfRSetVar('resourceParametersInitialized',true);
}

/**
 * @desc Insert javascript
 *
 */
function wtvInsertScripts(){
?>
<script type="text/javascript">
var currentChannel=<?php echo cfRGetVar('currentChannel');?>;
function winResized(){
	alignBottom($('mainDiv'),winMe,5)
	alignBottom($('mainLayoutTableTD'),$('mainDiv'),8)
}
function init(id){
	winResized();
	if(currentChannel>=0) playChannel(currentChannel);
}
function playChannel(id){
	D.comForm.target='playerIFrame';
	dgn('playerIFrame').style.display='';
	$('emptyDisplay').style.display='none';
	fAS(id,'view',"firstLoad",dgn('playerIFrame').offsetWidth+"x"+dgn('playerIFrame').offsetHeight);
}
function setType(type){
	wl.asr.send({'setType':type})
	var i,r=D.getElementsByName('radio');
	for(i=0;i<r.length;i++) r[i].style.display=(type=='radio')?'block':'none';
	r=D.getElementsByName('tv');
	for(i=0;i<r.length;i++) r[i].style.display=(type=='tv')?'block':'none';
}
init();
</script>
<?php
}

/**
 * @desc Return channel's icon
 *
 * @param string $channelName: plain channel name
 * @return string icon's url
 */
function wtvChannelIcon($channelName){
	static $icons=false;
	$iconsPackedFile=str_replace('\\','/',dirname(__FILE__)).'/icons.pack';

	// Get icons list from packed icons file
	if(!$icons)	{
		$tmp=cfPackedFileReadIndex($iconsPackedFile,true);
		$icons=array();
		foreach ($tmp as $k=>$v) $icons[strtolower(str_replace(array(' ','>','<','/','\\','?',':','*','|','"'),'',$k))]=$k;
		unset($tmp);
	}

	// Clean channel name to try to match with an icon name
	$channelName=strtolower(str_replace(array(' ','>','<','/','\\','?',':','*','|','"'),'',$channelName));
		if(strpos($channelName,'}')) $channelName=substr($channelName,0,strpos($channelName,'}'));

	// Found an icon with channel name: that's OK
	if(isset($icons[$channelName.'.gif'])) $file=$channelName.'.gif';
	// Else search for an icon starting with channel's name
	else{
		foreach ($icons as $iconName=>$stuff) {
			$iconName=substr($iconName,0,strlen($iconName)-4); // Remove GIF extension
			if(cfCmpLeft($channelName,$iconName)){$file=$iconName.'.gif';	break;}
			if($channelName==str_replace(array(' tv',' hd', ' hdtv'),'',$iconName)) {$file=$iconName.'.gif';	break;}
		}
		// No matching icon found, use default
		if(!isset($icons[@$file])) $file='default.gif';
	}


	$url=$_SERVER['PHP_SELF'].'?readOnlySession=1&cIcon='.cfBase64_url_encode($icons[$file]);

	return $url;
}

/**
 * @desc Return channel's icon
 *
 * @param string $channelName: plain channel name
 * @return string icon's url
 */
function wtvFlagIcon($cc){
	$url=$_SERVER['PHP_SELF'].'?readOnlySession=1&fIcon='.$cc;
	return $url;
}

/**
 * @desc Send channel's .gif icon to output
 *
 */
function wtvSendChannelIcon(){
	$iconsPackedFile=str_replace('\\','/',dirname(__FILE__)).'/icons.pack';
	$iconName=basename(cfBase64_url_decode($_GET['cIcon']));

	// Send headers
	WHeaders::contentType('gif');
	WHeaders::cache();

	// Send icon
	echo cfPackedFileRead($iconName,$iconsPackedFile);
	exit;
}

/**
 * @desc Send flag's .gif icon to output
 *
 */
function wtvSendFlagIcon(){
	$iconsPackedFile=str_replace('\\','/',dirname(__FILE__)).'/flags.pack';
	$iconName=$_GET['fIcon'].'.gif';

	// Send headers
	WHeaders::contentType('gif');
	WHeaders::cache();

	// Send icon
	echo cfPackedFileRead($iconName,$iconsPackedFile);
	exit;
}

/**
 * @desc Process commands sent through com form
 * 		 'view': play a channel (in iframe)
 *
 */
function wtvProcessPost(){
	global $playlist;

	// Channel request ($_POST['data2'] is channel id)
	if(@$_POST['data3']=='view' && isset($_POST['data2'])){
		// Ensure requested channel id exists
		$channelId=$_POST['data2'];

		if(!$playlist->track($channelId)) outDisplayErrorPage('Error: cannot find stream');;
		$track=$playlist->track($channelId);

		// Save viewed channel
		cfRSetVar('currentChannel',$channelId);

		// Set displayed video filename
		cfRSetVar('vvfForcedVideoName',$track['name']);

		// force channel external id into comform, to prevent url to be set in
		cfRSetVar('vvfForcedVideoExternalId',$channelId);

		// Get stream URL
		$url=$track['url'];

		// Retrieve and parse ASX file
		if(strpos($url,'asx')) $url=wtvGetASXUrl($url);
		// Note: if url couldn't be retrieved from asx url, do nothing and send asx file's URL as is. It might work... or display warning icon

		// Call video functions to display player and controls
		vfvViewVideo($url,@$_POST['data4'],@$_POST['data5'],array('externalFilename'=>$channelId,'streaming'=>1));
		exit;
	}

	// Set TV/Radio mode
	if(isset($_POST['setType'])){
		cfAsyncHeader();
		cfRSetVar('displayledChannelsType',($_POST['setType']=='radio')?'radio':'tv');
		die(cfAsyncFooter());
	}
}

/**
 * @desc Download and parse ASX file for stream URL
 *
 * @param string $asxUrl: url of ASX file
 * @return string
 */
function wtvGetASXUrl($asxUrl){
	// 1st, try in cache
	$cachedASXURLs=cfRGetVar('cachedASXURLs');
	if(isset($cachedASXURLs[$asxUrl])) return $cachedASXURLs[$asxUrl];

	// else retrieve and parse file
	$foo=false;
	$asxFile=cfSocketHTTPRequest($asxUrl,3,true,$foo,$foo,4096);
	//$asxFile=file_get_contents('C:/P1/webtv-asx.cgi'); if(0) cfDbg();
	if($asxFile){
		if(($p=strpos($asxFile,'href="'))){
			$p+=6;
			$p2=strpos($asxFile,'"',$p);
			if($p2){
				$tmpUrl=substr($asxFile,$p,$p2-$p);
				$cachedASXURLs[$asxUrl]=$tmpUrl;

				// Save result to cache
				cfRSetVar('cachedASXURLs',$cachedASXURLs);
				return $tmpUrl;
			}
		}
	}
}

require_once(INCLUDE_DIR.'viewVideoFunctions.php');
require_once(INCLUDE_DIR.'explorerFunctions.php');
require_once(INCLUDE_DIR.'outputFunctions.php');

// Just include functions if called from /ext/video.php
if(isset($included)) return;

// Init resource
wtvInit();

// Channel icon
if(isset($_GET['cIcon'])) wtvSendChannelIcon();

// Flag icon
if(isset($_GET['fIcon'])) wtvSendFlagIcon();

// Get and parse playlist
if(0) $playlist=new WtvPlaylist('foo');
$playlist=unserialize(cfRGetVar('playlist'));

// Process POST commands
wtvProcessPost();

// Mobile view
if(cfIsMobile()) require(dirname(__FILE__).'/mobileIndex.php');
// Included by /ext/video.php
if(defined('SESSION_NAME_PREFIX')) return;


/*
 ***************************************************************************************************************************
 * Insert HEAD, JS functions
 ***************************************************************************************************************************
 */
cfInsertHEAD(true);
echo '<body style="overflow:hidden">';

outInsertStandardComForm();

echo outDivFrame('frame1','id="mainDiv"');

echo outTableTransparent(false,'table-layout:fixed;height:100%;overflow:auto','id="mainLayoutTable"');
echo '<tr><td style="width:200px;height:100%;vertical-align:top;overflow:hidden" class="vBanner" id="mainLayoutTableTD">';
echo '<div style="width:100%;height:100%;overflow:auto">';

/**
 * TV / Radio selector
 */
if($playlist->length('tv')>0 && $playlist->length('radio')>0){
	echo '<div class="frame1Header">';
	echo outBlockItem('typeSelect','<img src="tv.png" alt="tv" style="margin:0 20px 0 20px">',false,'padding:10px',array('onclick'=>"setType('tv')"),(cfRGetVar('displayledChannelsType')=='tv')?'sel':'unsel');
	echo outBlockItem('typeSelect','<img src="radio.png" alt="radio" style="margin:0 20px 0 20px">',false,'padding:10px',array('onclick'=>"setType('radio')"),(cfRGetVar('displayledChannelsType')=='radio')?'sel':'unsel');
	echo '</div>';
}


/*
 ***************************************************************************************************************************
 * Display channels
 ***************************************************************************************************************************
 */
?>
<style type="text/css">
.flag{width;16px;height:11px;position:absolute;top:8px;left:4px;opacity:0.9}
.channel{width:52px;height:39px;vertical-align:middle;margin-right:0.5em;float:left}
</style>
<?php


$type=cfRGetVar('displayledChannelsType');
foreach ($playlist->tracks() as $k=>$v){
	$style='display:block';
	if($v['type']!==$type) $style.=';display:none';
	echo outBlockItem($v['type'],
		'<img src="'.wtvChannelIcon($v['name']).'" class="channel">'.
		(($v['country'])?'<img src="'.wtvFlagIcon($v['country']).'" class="flag">':'').
		'<div style="margin-top:4px">'.cfUTF8Encode(str_replace('}','',$v['name'])).'</div>',
		false,
		$style,
		array('onclick'=>'playChannel(\''.$k.'\')'),
		($k==cfRGetVar('currentChannel'))?'sel':'unsel'
	);
}
echo '</td><td style="vertical-align:top">';

/*
 ***************************************************************************************************************************
 * Video iframe
 ***************************************************************************************************************************
 */
?>
<iframe src="/gfx/v.gif" name="playerIFrame" style="width:100%;height:100%;border:0;display:none" frameborder="0"></iframe>
<img id="emptyDisplay" src="<?php echo WEnv::res()->config()->icon32();?>" style="position:absolute;left:50%;top:50%;margin:-16px 0 0 84px">
<?php
echo '</td></tr></table>';
wtvInsertScripts();