<?php
/**
 * Webcam configuration file
 *
 * Configuration of standard photo album resource
 * this script is included by /res/administration/std/resourceConfig.php
 * this script should never be directly called.
 *
 * resourceConfig.php sets 2 variables :
 * $resourceData (array) which contains resource parameters
 * $_ENV['configurationEnvironment'] which indicates if resourceConfig.php has been called from browser ('browser')
 * or from application's embeded browser ('application')
 *
 * PHP version 5
 *
 * LICENSE: This source file is subject to version 3.0 of the PHP license
 * that is available through the world-wide-web at the following URI:
 * http://www.php.net/license/3_0.txt.  If you did not receive a copy of
 * the PHP License and are unable to obtain it through the web, please
 * send a note to license@php.net so we can mail you a copy immediately.
 *
 * @category   NA
 * @package    NA
 * @author     Nicolas Bruley / Peer 2 World <contact@weezo.net>
 * @copyright  2013-2013 Nicolas Bruley / Peer 2 World
 * @license    http://www.php.net/license/3_0.txt  PHP License 3.0
 * @version    CVS: $Id:$
 * @link       http://www.weezo.net
 * @since      File available since Release 4.2.0
 */


// Use legacy method if set by user
if(@$resourceData['webcamMethod']=='AVICap'){
	require(dirname(__FILE__).'/../std.old/disabled/config.php');
	return;
}

require(INCLUDE_DIR.'webcamFunctions.php');

/*
 ***************************************************************************************************************************
 * Verify config rights
 ***************************************************************************************************************************
 */
rcConfigRights();

$webcams=webcamGetList(!isset($_POST['detect']));

if(isset($_POST['detect'])) {
	cfAsyncHeader();
	echo cfAsyncJSaction('wl.goURL()');
	cfAsyncFooter();
}

/*
 ***************************************************************************************************************************
// Display configuration form
 ***************************************************************************************************************************
*/

// Insert Javascript function needed for save button activation, and <form> with hidden fields.
rcInsertScriptAndForm();

// Resource icon & name
rcInsertIconName($resourceData);

// Webcam method: AVICap for legacy method, ffmpeg for ffmpeg-based method
if(WEnv::host()->isWindows()) echo outBt('AVICap',outIcon('alt'),"javascript:toggleMethod('AVICap')",false,cfCaption('webcamAlternateMethod'),'style="float:right;margin-right:1em"');
echo '<div style="display:none">';
rcProcessData('webcamMethod',dataList,'ffmpeg',array('ffmpeg','AVICap'),array(
	array('','webcam method'),array(
	array('ffmpeg','ffmpeg method'),
	array('AVICap','AVICap method')),
	false), false
);
echo '</div>';

/**
 * No detected webcam
 */
if(!@count($webcams['video'])){
	echo '<div class="extendedWarning" style="margin:10% 10em 0 10em;text-align:center"><br><br>'.cfCaption('webcamError').'<br><br>';

	echo outBt(cfCaption('genRefresh'),outIcon('reload2'),'javascript:(function(){wl.mask.show(0,0); sendData(\'detect=1\',undefined,true,3)})()');

	echo '<br>&nbsp;</div>';
	echo '<br/>'.rcButtonSaveCancel();
	return;
}

/**
 * Webcam video and audio sources
 */
echo '<h2>'.cfCaption('webcamSource').'&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
// Lock video/audio source
rcProcessData('sourceLocked',dataBoolean,false,false,array(outIcon('lock'),outIcon('lockOpened')),false);
echo '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
echo outBt(cfCaption('genRefresh'),outIcon('reload2'),'javascript:(function(){wl.mask.show(0,0); sendData(\'detect=1\',undefined,true,3)})()');

echo '</h2><br>';

$ids=array();
$controls=array();

/**
 * Video source
 */
foreach ($webcams['video'] as $id=>$desc){

	// Use only webcams with found resolution
	if(!$desc['resolution']) continue;

	if(!isset($defaultId)) $defaultId=$id;
	$ids[]=$id;
	$controls[]=array($id,$desc['label'].' ('.(($desc['resolution']=='0x0')?'?x?':$desc['resolution']).')');
}

if(!isset($defaultId)) {
	echo outDivFrame('extendedWarning').cfCaption('webcamError').'</div>';
}
else
	rcProcessData('videoSource',dataList,$defaultId,$ids,array(
		array(false,outImageIcon('webcam32')),
		$controls,false),true);


/**
 * Audio source
 */
$ids=array();
$controls=array();
unset($default);
unset($defaultId);

foreach ($webcams['audio'] as $id=>$desc){
	// Use only webcams with found resolution
	if(!$desc['capabilities']) continue;

	if(!isset($defaultId)) $defaultId=$id;
	$ids[]=$id;
	$controls[]=array($id,$desc['label']);
}
echo '<br>';

if(isset($defaultId))
	rcProcessData('audioSource',dataList,$defaultId,$ids,array(
		array(false,outImageIcon('webcamMicro32')),
		$controls,false),true);

echo outConfigSeparator();

/**
 * Render type (video / still images)
 */
echo '<h2>'.cfCaption('genDisplay').'&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
// Lock render type
rcProcessData('renderingLocked',dataBoolean,false,false,array(outIcon('lock'),outIcon('lockOpened')),false);
echo '</h2><br>';

// Webcam refresh rate for still images
echo '<div style="position:absolute;left:100px;margin-top:8px" id="refreshDiv">';
rcProcessData('refreshRate',dataNumeric,10,array(2,1000),array(cfCaption('genRefreshRate'),2,cfCaption('genSeconds')));
echo '</div>';

// Still image / video
rcProcessData('stillImages',dataBoolean,false,false,array(outImageIcon('webcamImages').'<br><br>',outIcon('webcamVideo')),true);


//echo cfCaption('videoCfgFlashSize');


// Allow full-size view
rcProcessData('flashOutputSizeMax',dataText,'original',false,false/*do not display control*/);
// Allow max-quality
rcProcessData('flashOutputQualityMax',dataText,'original',false,false/*do not display control*/);


rcProcessData('userTempDirAccessAllowed',dataBoolean,false,false,false/*do not display control*/); // Allow/Forbid access to user temp directory (data/sessiondata/(session_id)/)
rcProcessData('resourceDataDirAccessAllowed',dataBoolean,true,false,false/*do not display control*/); // Allow/Forbid access to resource directory (data/res/(res type)/(res subType)/(res file name)/)

rcProcessData('defaultWindowWidth',dataNumeric,370,false,false/*do not display control*/); // Default windows width
rcProcessData('defaultWindowHeight',dataNumeric,310,false,false/*do not display control*/); // Default windows height




// Save / cancel buttons
echo '<br/>'.rcButtonSaveCancel();

// If resource need access to resource data dir, create it
rcCreateResourceDataDir();

// Indicate that resource has been configured once
rcProcessData('resourceConfigured',dataBoolean,true,false,false/*do not display control*/);

// Save parameters
rcWriteResourceFile($resourceData, $fileName,true); // Force commit to app as some parameters need to be synched (remote desktop)
?>
<script type="text/javascript">
// Toggle AVICap / ffmpeg methods
function toggleMethod(newMethod){
	dgn('webcamMethod').value=newMethod;
	eSaveBt('webcamMethod',newMethod);
	setTimeout(wl.goURL,1000)
}

function dataChanged(dataName,dataValue){
	if(dataName=="stillImages") $('refreshDiv').e.setOpacity((dataValue && dataValue!=='false')?1:0.2)
}
dataChangedNV("stillImages");
</script>